@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.client/examples/job_status.c,v 1.31.10.1 2012/05/25 12:14:11 jfilipov Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.client/examples/job_status.c,v 1.36 2012/08/08 15:48:39 zsustr Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -31,6 +31,7 @@ limitations under the License.
 #endif
 #include "glite/lb/xml_conversions.h"
 #include "glite/lb/jobstat.h"
+#include "glite/lb/events_parse.h"
 
 static void dgerr(edg_wll_Context,char *);
 static void printstat(edg_wll_JobStat,int);
@@ -246,6 +247,9 @@ static void printstat(edg_wll_JobStat stat, int level)
 		case EDG_WLL_STAT_FILE_TRANSFER_COLLECTION:
 			printf("%sjobtype : FILE_TRANSFER_COLLECTION\n", ind);
                         break;
+		case EDG_WLL_STAT_VIRTUAL_MACHINE:
+			printf("%sjobtype : VIRTUAL_MACHINE\n", ind);
+                        break;
 		default:
 			printf("%sjobtype : UNKNOWN\n", ind);
 			break;
@@ -343,7 +347,7 @@ static void printstat(edg_wll_JobStat stat, int level)
 		printf("%spbs_dest_host : %s\n", ind, stat.pbs_dest_host);
 		printf("%spbs_pid : %d\n", ind, stat.pbs_pid);
 		printf("%spbs_resource_usage : %s%s\n", ind,
-			(stat.pbs_resource_usage) ? "\n" : "", stat.pbs_resource_usage);
+		       (stat.pbs_resource_usage) ? "\n" : "", edg_wll_TagListToString(stat.pbs_resource_usage));
 		printf("%spbs_exit_status : %d\n", ind, stat.pbs_exit_status);
 		printf("%spbs_error_desc : %s%s\n", ind, 
 			(stat.pbs_error_desc) ? "\n" : "", stat.pbs_error_desc);
@@ -377,7 +381,18 @@ static void printstat(edg_wll_JobStat stat, int level)
 		printf("%sft_sandbox_type : UNKNOWN\n", ind);
 	printf("%sft_src : %s\n", ind, stat.ft_src);
 	printf("%sft_dest : %s\n", ind, stat.ft_dest);
-	
+
+	char *vm_stat_name = edg_wll_VMStatToString(stat.vm_state);
+	if (stat.jobtype == EDG_WLL_STAT_VIRTUAL_MACHINE){
+		printf("%svm_state : %s\n", ind, vm_stat_name);
+		printf("%svm_hostname : %s\n", ind, stat.vm_hostname);
+		printf("%svm_image : %s\n", ind, stat.vm_image);
+		printf("%svm_require : %s\n", ind, stat.vm_require);
+		printf("%svm_usage : %s\n", ind, stat.vm_usage);
+		printf("%svm_name : %s\n", ind, stat.vm_name);
+		printf("%svm_id : %s\n", ind, stat.vm_id);
+		printf("%svm_phy_hostname : %s\n", ind, stat.vm_phy_hostname);
+	}	
 
 	printf("\n");	
 	
